@@ -26,7 +26,7 @@ if settings.FORCE_SCRIPT_NAME:
 	DYNAMIC_LINK_URL = settings.FORCE_SCRIPT_NAME + '/' + DYNAMIC_LINK_URL_BASE_COMPONENT
 else:
 	DYNAMIC_LINK_URL = '/' + DYNAMIC_LINK_URL_BASE_COMPONENT
-DYNAMIC_LINK_URL = DYNAMIC_LINK_URL_BASE_COMPONENT.replace('//', '/')
+DYNAMIC_LINK_URL = DYNAMIC_LINK_URL.replace('//', '/')
 
 # Uploaded files base directory
 DYNAMIC_LINK_UPLOAD_TO = getattr(
